import { ApiPropertyOptional } from "@nestjs/swagger";
import { Transform, Type } from "class-transformer";
import { IsOptional, IsPositive, IsString, IsUUID, ValidateNested } from "class-validator";

class Runtime {
  @Transform(({ value }) => +value)
  @IsOptional()
  @IsPositive()
  @ApiPropertyOptional({name: 'runtime[gte]'})
  gte?: number;

  @Transform(({ value }) => +value)
  @IsOptional()
  @IsPositive()
  @ApiPropertyOptional({name: 'runtime[lte]'})
  lte?: number;
}

class Published {
  @Transform(({ value }) => +value)
  @IsOptional()
  @IsPositive()
  @ApiPropertyOptional({name: 'published[gte]'})
  gte?: number;

  @Transform(({ value }) => +value)
  @IsOptional()
  @IsPositive()
  @ApiPropertyOptional({name: 'published[lte]'})
  lte?: number;
}

export class IMoviesQuery {
  @Transform(({ value }) => +value)
  @IsOptional()
  @IsPositive()
  @ApiPropertyOptional({name: 'mostRecentCnt'})
  mostRecentCnt?: number;

  @IsOptional()
  @IsString()
  @ApiPropertyOptional({name: 'name'})
  name?: string;

  @IsOptional()
  @IsString()
  @ApiPropertyOptional({name: 'origName'})
  origName?: string;

  @ValidateNested({ each: true })
  @Type(() => Runtime)
  @IsOptional()
  @ApiPropertyOptional({ type: () => Runtime })
  runtime?: Runtime;

  @ValidateNested({ each: true })
  @Type(() => Published)
  @IsOptional()
  @ApiPropertyOptional({ type: () => Published })
  published?: Published;

  @IsOptional()
  @IsUUID()
  @ApiPropertyOptional({name: 'categoryId'})
  categoryId?: string;

  @IsOptional()
  @IsUUID()
  @ApiPropertyOptional({name: 'directorId'})
  directorId?: string;
};
