import {
  Card,
  Collapse,
  Image,
  Space,
  List,
} from "antd";
import Meta from "antd/lib/card/Meta";
import { useEffect, useState } from "react";
import { Link } from "react-router-dom";
import { CategoryIO } from "./Preview";
import axiosConfig from "../axios-config";
import { ErrorPage } from "./ErrorPage";

const { Panel } = Collapse;

// for browsing movies by categories
export const BrowseMovies = () => {
  const [categories, setCategories] = useState<CategoryIO[]>([]);
  const [isError, setIsError] = useState<boolean>(false);

  useEffect(() => {
    const fetchCategories = async () => {
      try {
        const response = await axiosConfig.get("categories");
        setCategories(response.data);
      } catch (err) {
        setIsError(true);
      }
    }

    void fetchCategories();
  }, [])

  if (isError) {
    return <ErrorPage />
  }

  return (
    <div className="browse-container">
      <Space direction="vertical" style={{ padding: "3rem" }} wrap>
        <Collapse>
          {categories.map((category) => {
            return (
              <Panel header={category.name} key={category.id}>

<List
    grid={{
      gutter: 16,
      xs: 1,
      sm: 2,
      md: 2,
      lg: 2,
      xl: 4,
      xxl: 6,
    }}
    dataSource={category.movies}
    rowKey="id"
    pagination={{
      pageSize: 6,
    }}
    renderItem={movie => (
      <List.Item>
        <Space>
        <Card
                        cover={
                          <Image
                            width={200}
                            style={{ objectFit: "cover" }}
                            src={movie.picture}
                          ></Image>
                        }
                      >
                        <Link to={`/movie/${movie.id}`}>
                          <Meta
                            title={movie.name}
                            description={
                              <div>
                                {movie.originalName}
                                <br></br>
                                {movie.publishedAt}
                              </div>
                            }
                          ></Meta>
                        </Link>
                      </Card>
                      </Space>
      </List.Item>
    )}
  />



                {category.movies.map((movie) => {
                  return (
                    <Space>

                    </Space>
                  );
                })}
              </Panel>
            );
          })}
        </Collapse>
      </Space>
    </div>
  );
};
